@@ -31,13 +31,13 @@ from naas_drivers.inputOutput.notion import Notion
 from naas_drivers.inputOutput.hubspot import Hubspot
 from naas_drivers.inputOutput.thinkific import Thinkific
 from naas_drivers.input.markdown import Markdown
-from naas_drivers.output.streamlit import NaasStreamlit  # noqa: F401
-from naas_drivers.input.nlp import NLP
+from naas_drivers.output.streamlit import Streamlit
+from naas_drivers.input.huggingface import Huggingface
 
 import requests
 import os
 
-__version__ = "0.70.3"
+__version__ = "0.70.7"
 
 __github_repo = "jupyter-naas/drivers"
 
@@ -62,7 +62,7 @@ markdown = Markdown()
 teams = Teams()
 slack = Slack()
 qonto = Qonto()
-nlp = NLP()
+huggingface = Huggingface()
 
 # Out drivers
 bubble = Bubble()
@@ -71,6 +71,7 @@ healthcheck = Healthcheck()
 ifttt = Ifttt()
 integromat = Integromat()
 zappier = Zappier()
+streamlit = Streamlit()
 
 # InOut drivers
 bobapp = Bobapp()
